/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file contains the necessary initialization of the ST7789V display
*   controller and the necessary function to update a rectangular area of the
*   screen from an Embedded Wizard UI application.
*   The data transfer is done by using the hardware GPIO controller via DMA.
*   The color format of the display is RGB565.
*
*******************************************************************************/

#pragma once


/*******************************************************************************
 * Initializes GPIOs for the i8080 8-bit interface.
 *******************************************************************************/
void st7789v_i8080_init( void );


/*******************************************************************************
 * Free all resources used for the software i8080 interface.
 *******************************************************************************/
void st7789v_i8080_done(void);


/*******************************************************************************
 * Sets value of the display Reset pin.
 *******************************************************************************/
void st7789v_i8080_reset( bool value );


/*******************************************************************************
 * Writes one byte of data to the software i8080 interface with the LCD_DC pin
 *******************************************************************************/
void st7789v_i8080_write_command(uint8_t data);


/*******************************************************************************
 * Writes one byte of data to the software i8080 interface with the LCD_DC pin
 *******************************************************************************/
void st7789v_i8080_write_data(uint8_t data);


/*******************************************************************************
 * Writes multiple bytes of data to the software i8080 interface with the LCD_DC
 * pin set to 1.
 *******************************************************************************/
void st7789v_i8080_write_data_stream(uint8_t *data, int num);
