/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target.
*   This template provides access to some LEDs and buttons of the board.
*
*******************************************************************************/

#include "cy_pdl.h"
#include "cyhal.h"
#include "cybsp.h"

#include "ewconfig.h"
#include "ew_bsp_inout.h"

#define USER_BTN_INTERRUPT_PRIORITY (7u)

static TButtonCallback            UserButtonCallback;
static cyhal_gpio_callback_data_t CyHalUserButtonCallbackData;

/*******************************************************************************
* FUNCTION:
*   EwBspGGpioIrqHandler
*
* DESCRIPTION:
*   The GPIO interrupt callback function.
*
* ARGUMENTS:
*   GPIO_Pin - the gpio pin.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspGGpioIrqHandler( void *handler_arg, cyhal_gpio_event_t event )
{
  int       pinState = 1;

  if ( cyhal_gpio_read( CYBSP_USER_BTN ))
    pinState = 0;

  if ( UserButtonCallback )
    UserButtonCallback( pinState );
}


/*******************************************************************************
* FUNCTION:
*   EwBspInOutInitButton
*
* DESCRIPTION:
*   Configures one hardware button of the board used for demo applications.
*
* ARGUMENTS:
*   aButtonCallback - The button callback.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspInOutInitButton( TButtonCallback aButtonCallback )
{
  memset( &CyHalUserButtonCallbackData, 0, sizeof( CyHalUserButtonCallbackData ));

  CyHalUserButtonCallbackData.pin      = CYBSP_USER_BTN;
  CyHalUserButtonCallbackData.callback = EwBspGGpioIrqHandler;

  /* Initialize the user button */
  cyhal_gpio_init( CYBSP_USER_BTN, CYHAL_GPIO_DIR_INPUT,
    CYHAL_GPIO_DRIVE_PULLUP, CYBSP_BTN_OFF );

  /* Configure GPIO interrupt */
  cyhal_gpio_register_callback( CYBSP_USER_BTN, &CyHalUserButtonCallbackData );
  cyhal_gpio_enable_event( CYBSP_USER_BTN, CYHAL_GPIO_IRQ_BOTH,
		  USER_BTN_INTERRUPT_PRIORITY, true );

  UserButtonCallback = aButtonCallback;
}


/*******************************************************************************
* FUNCTION:
*   EwBspInOutInitLed
*
* DESCRIPTION:
*   Configures one LED of the board used for demo applications.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspInOutInitLed( void )
{
  /* Initialize the User LED */
  cyhal_gpio_init( CYBSP_USER_LED, CYHAL_GPIO_DIR_OUTPUT,
    CYHAL_GPIO_DRIVE_STRONG, CYBSP_LED_STATE_OFF );
}


/*******************************************************************************
* FUNCTION:
*   EwBspInOutLedOn
*
* DESCRIPTION:
*   Switch LED on (used for demo applications).
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspInOutLedOn( void )
{
  cyhal_gpio_write( CYBSP_USER_LED, CYBSP_LED_STATE_ON );
}


/*******************************************************************************
* FUNCTION:
*   EwBspInOutLedOff
*
* DESCRIPTION:
*   Switch LED off (used for demo applications).
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspInOutLedOff( void )
{
  cyhal_gpio_write( CYBSP_USER_LED, CYBSP_LED_STATE_OFF );
}


/* mli */
